import {debounce, byId, queryAll} from './yts-util.mjs';
import {getSavedOptions} from './saved-settings-misc.mjs';

// Saves options to chrome.storage
function saveUserConfig() {
    chrome.storage.sync.set({
        "ctrl.leftArrow": byId("ctrl.leftArrow").value,
        "ctrl.rightArrow": byId("ctrl.rightArrow").value,
        "ctrl.shift.leftArrow": byId("ctrl.shift.leftArrow").value,
        "ctrl.shift.rightArrow": byId("ctrl.shift.rightArrow").value,

        "showShortRewindButton": byId("showShortRewindButton").checked,
        "showLongRewindButton": byId("showLongRewindButton").checked,
        "showShortForwardButton": byId("showShortForwardButton").checked,
        "showLongForwardButton": byId("showLongForwardButton").checked,

        "showSeekButtonTooltips": byId("showSeekButtonTooltips").checked,

        "useRectangularStyleButtons": byId("useRectangularStyleButtons").checked,

        "enableYoutubeComHotkeys": byId("enableYoutubeComHotkeys").checked,
        "enableNonYoutubeComHotkeys": byId("enableNonYoutubeComHotkeys").checked,

        "enableTimePositionMemoryForClickedSeekBar": byId("enableTimePositionMemoryForClickedSeekBar").checked,
        "enableTimePositionMemoryForPageReloads": byId("enableTimePositionMemoryForPageReloads").checked,
    }, showConfigSavedSuccessIndicator);
}

function showConfigSavedSuccessIndicator() {
    const status = byId('status');
    status.classList.remove("hidden");
    status.classList.add("visible");
    status.textContent = "Config Saved.";
    setTimeout(() => {
        status.classList.remove("visible");
        status.classList.add("hidden");
    }, 200);
}

function restoreUserConfig() {
    getSavedOptions().then(vals => {
        byId("ctrl.leftArrow").value = vals["ctrl.leftArrow"];
        byId("ctrl.rightArrow").value = vals["ctrl.rightArrow"];
        byId("ctrl.shift.leftArrow").value = vals["ctrl.shift.leftArrow"];
        byId("ctrl.shift.rightArrow").value = vals["ctrl.shift.rightArrow"];
        byId("showShortRewindButton").checked = vals["showShortRewindButton"];
        byId("showLongRewindButton").checked = vals["showLongRewindButton"];
        byId("showShortForwardButton").checked = vals["showShortForwardButton"];
        byId("showLongForwardButton").checked = vals["showLongForwardButton"];
        byId("showSeekButtonTooltips").checked = vals["showSeekButtonTooltips"];
        byId("useRectangularStyleButtons").checked = vals["useRectangularStyleButtons"];
        byId("enableYoutubeComHotkeys").checked = vals["enableYoutubeComHotkeys"];
        byId("enableNonYoutubeComHotkeys").checked = vals["enableNonYoutubeComHotkeys"];
        byId("enableTimePositionMemoryForClickedSeekBar").checked = vals["enableTimePositionMemoryForClickedSeekBar"];
        byId("enableTimePositionMemoryForPageReloads").checked = vals["enableTimePositionMemoryForPageReloads"];
    });
}

function init() {
    restoreUserConfig();
    const manifest = chrome.runtime.getManifest();
    byId('extension-version-num').textContent = manifest.version;
    byId('extension-name').textContent = manifest.name;
    showMacExtraHotkeyButtons();
    showDevMode();
}

function showMacExtraHotkeyButtons() {
    chrome.runtime.getPlatformInfo(function(info) {
        if (info.os === 'mac') {
            Array.from(document.querySelectorAll('.mac-command-additional-button')).forEach(el => {
                el.hidden = false;
            });
        }
    });
}

function showDevMode() {
    const manifest = chrome.runtime.getManifest();
    if (manifest.name.includes(' dev')) {
        Array.from(document.querySelectorAll('.dev-visible')).forEach(el => {
            el.style.display = '';
        });
    }
}

document.addEventListener('DOMContentLoaded', init);

// Use input event on all elements to trigger a save.
// But, we debounce it, and only do the save if there's been no activity for a bit.
// This way we don't spam save as they type.
const markFormUpdated = debounce(saveUserConfig, 500);
queryAll("input").forEach(input => {
    input.addEventListener("input", markFormUpdated, false);
});